@@ -151,8 +151,8 @@ namespace xsimd
 
         operator __m256i() const;
 
-        avx_int_batch& load_aligned(const T* src);
-        avx_int_batch& load_unaligned(const T* src);
+        batch<T, N>& load_aligned(const T* src);
+        batch<T, N>& load_unaligned(const T* src);
 
         void store_aligned(T* dst) const;
         void store_unaligned(T* dst) const;
@@ -193,12 +193,12 @@ namespace xsimd
         {
         }
 
-        base_class& load_aligned(const char* src)
+        batch& load_aligned(const char* src)
         {
             return load_aligned(reinterpret_cast<const int8_t*>(src));
         }
 
-        base_class& load_unaligned(const char* src)
+        batch& load_unaligned(const char* src)
         {
             return load_unaligned(reinterpret_cast<const int8_t*>(src));
         }
@@ -503,17 +503,17 @@ namespace xsimd
     }
 
     template <class T, std::size_t N>
-    inline avx_int_batch<T, N>& avx_int_batch<T, N>::load_aligned(const T* src)
+    inline batch<T, N>& avx_int_batch<T, N>::load_aligned(const T* src)
     {
         m_value = _mm256_load_si256((__m256i const*) src);
-        return *this;
+        return (*this)();
     }
 
     template <class T, std::size_t N>
-    inline avx_int_batch<T, N>& avx_int_batch<T, N>::load_unaligned(const T* src)
+    inline batch<T, N>& avx_int_batch<T, N>::load_unaligned(const T* src)
     {
         m_value = _mm256_loadu_si256((__m256i const*) src);
-        return *this;
+        return (*this)();
     }
 
     template <class T, std::size_t N>
