@@ -112,8 +112,8 @@ namespace xsimd
 
         operator __m128i() const;
 
-        sse_int_batch& load_aligned(const T* src);
-        sse_int_batch& load_unaligned(const T* src);
+        batch<T, N>& load_aligned(const T* src);
+        batch<T, N>& load_unaligned(const T* src);
 
         void store_aligned(T* dst) const;
         void store_unaligned(T* dst) const;
@@ -154,12 +154,12 @@ namespace xsimd
         {
         }
 
-        base_class& load_aligned(const char* src)
+        batch& load_aligned(const char* src)
         {
             return load_aligned(reinterpret_cast<const int8_t*>(src));
         }
 
-        base_class& load_unaligned(const char* src)
+        batch& load_unaligned(const char* src)
         {
             return load_unaligned(reinterpret_cast<const int8_t*>(src));
         }
@@ -395,17 +395,17 @@ namespace xsimd
     }
 
     template <class T, std::size_t N>
-    inline sse_int_batch<T, N>& sse_int_batch<T, N>::load_aligned(const T* src)
+    inline batch<T, N>& sse_int_batch<T, N>::load_aligned(const T* src)
     {
         m_value = _mm_load_si128((__m128i const*)src);
-        return *this;
+        return (*this)();
     }
 
     template <class T, std::size_t N>
-    inline sse_int_batch<T, N>& sse_int_batch<T, N>::load_unaligned(const T* src)
+    inline batch<T, N>& sse_int_batch<T, N>::load_unaligned(const T* src)
     {
         m_value = _mm_loadu_si128((__m128i const*)src);
-        return *this;
+        return (*this)();
     }
 
     template <class T, std::size_t N>
@@ -468,6 +468,11 @@ namespace xsimd
                 XSIMD_MACRO_UNROLL_BINARY(/);
             }
 
+            static batch_type mod(const batch_type& lhs, const batch_type& rhs)
+            {
+                XSIMD_MACRO_UNROLL_BINARY(%);
+            }
+
             static batch_bool_type eq(const batch_type& lhs, const batch_type& rhs)
             {
                 return _mm_cmpeq_epi8(lhs, rhs);
